==> scran_1.10.2.tar.gz: scran/src/scran.h <==
#ifndef SCRAN_H
#define SCRAN_H

#include "beachmat/integer_matrix.h"
#include "beachmat/numeric_matrix.h"
#include "Rcpp.h"

#include <stdexcept>
#include <algorithm>
#include <deque>
#include <vector>
#include <cmath>

extern "C" {

// Normalization.

SEXP forge_system (SEXP, SEXP, SEXP, SEXP);

SEXP subset_and_divide(SEXP, SEXP, SEXP, SEXP); 

SEXP simple_sum_factors(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);

// Cell cycle calling.

SEXP shuffle_scores (SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP auto_shuffle(SEXP, SEXP);

// Correlation calclulations.

SEXP get_null_rho (SEXP, SEXP);

SEXP get_null_rho_design (SEXP, SEXP, SEXP);

SEXP rank_subset(SEXP, SEXP, SEXP, SEXP);

SEXP compute_rho(SEXP, SEXP, SEXP, SEXP);

SEXP combine_corP(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);

// Variance calculations.

SEXP fit_linear_model(SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP fit_oneway(SEXP, SEXP, SEXP);

SEXP calc_log_count_stats(SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP calc_log_expected(SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP calc_log_sqdiff(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);

// DE analysis functions.

SEXP combine_simes(SEXP, SEXP);

SEXP overlap_exprs(SEXP, SEXP, SEXP, SEXP);

// Clustering functions.

SEXP get_scaled_ranks(SEXP, SEXP, SEXP, SEXP);

SEXP build_snn_rank(SEXP);

SEXP build_snn_number(SEXP);

// Miscellaneous functions.

SEXP get_residuals(SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP compute_CV2(SEXP, SEXP, SEXP, SEXP);

SEXP shuffle_matrix(SEXP);

// MNN calculations.

SEXP find_mutual_nns(SEXP, SEXP);

SEXP cosine_norm(SEXP, SEXP);

SEXP smooth_gaussian_kernel(SEXP, SEXP, SEXP, SEXP);

SEXP adjust_shift_variance(SEXP, SEXP, SEXP, SEXP);

}

#include "utils.h"

#endif

==> scran_1.12.0.tar.gz: scran/src/scran.h <==
#ifndef SCRAN_H
#define SCRAN_H

#include "Rcpp.h"

extern "C" {

// Normalization.

SEXP pool_size_factors(SEXP, SEXP, SEXP, SEXP);

SEXP subset_and_divide(SEXP, SEXP, SEXP, SEXP); 

// Cell cycle calling.

SEXP cyclone_scores (SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);

// Correlation calclulations.

SEXP get_null_rho(SEXP, SEXP, SEXP, SEXP);

SEXP get_null_rho_design(SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP test_rnorm(SEXP, SEXP, SEXP);

SEXP compute_rho_pairs(SEXP, SEXP, SEXP);

SEXP combine_rho(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);

// Test shuffling functions.

SEXP test_shuffle_vector(SEXP, SEXP, SEXP, SEXP);

SEXP test_shuffle_matrix(SEXP, SEXP, SEXP);

// Variance calculations.

SEXP fit_linear_model(SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP fit_oneway(SEXP, SEXP, SEXP);

SEXP calc_log_count_stats(SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP calc_log_expected(SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP calc_log_sqdiff(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);

// DE analysis functions.

SEXP combine_simes(SEXP, SEXP);

SEXP overlap_exprs(SEXP, SEXP, SEXP, SEXP);

// Clustering functions.

SEXP get_scaled_ranks(SEXP, SEXP, SEXP, SEXP);

SEXP build_snn_rank(SEXP);

SEXP build_snn_number(SEXP);

// Miscellaneous functions.

SEXP get_residuals(SEXP, SEXP, SEXP, SEXP, SEXP);

SEXP compute_CV2(SEXP, SEXP, SEXP, SEXP);

SEXP shuffle_matrix(SEXP, SEXP, SEXP);

// MNN calculations.

SEXP find_mutual_nns(SEXP, SEXP);

SEXP cosine_norm(SEXP, SEXP);

SEXP smooth_gaussian_kernel(SEXP, SEXP, SEXP, SEXP);

SEXP adjust_shift_variance(SEXP, SEXP, SEXP, SEXP);

}

#endif
